# -*- coding: utf-8 -*-

#  PycaWM
#  decorators.py
#  Copyright (c) 2007 Vincent Rasneur, Anaël Verrier

#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; version 3 only.

#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.

#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

import sys

if sys.version_info < (2, 5):
    raise ImportError('decorators module needs at least Python 2.5!')

from functools import wraps

def managed_client(fun):
    """Decorator which retrieves the (managed) client from an X11 event.
    It then calls the decorated function with the object, the event and
    the client.
    If there is no client found, nothing happens.
    """
    @wraps(fun)
    def wrapper(self, event):
        client = self.get_managed_client(event.window)
        if client:
            return fun(self, event, client)
    return wrapper
